@@ -20,32 +20,6 @@ _maix_module = Extension('_maix', include_dirs=['ext_modules/_maix/include', 'ex
     ],
 )
 
-# python3.8 -m pip install pybind11
-_maix_opencv_module = Pybind11Extension(
-    name = "_maix_opencv",
-    include_dirs=[
-        get_incs(
-            'ext_modules/libmaix/components/libmaix/include'),
-        get_incs(
-            'ext_modules/libmaix/components/libmaix/lib/arch/r329/include/opencv4/'),
-        get_incs(
-            'ext_modules/libmaix/components/maix_cv_image/include')
-    ],
-    sources=get_srcs('ext_modules/_maix_opencv') + get_srcs('ext_modules/libmaix/components/maix_cv_image/src'),
-    libraries=[
-        "maix_image","maix_disp", "opencv_videoio", "opencv_highgui", "opencv_core", "opencv_imgproc", "opencv_imgcodecs", "opencv_freetype"
-    ],
-    library_dirs=["./ext_modules/libmaix/components/libmaix/lib/arch/r329/opencv4",
-        ext_so
-    ],
-    extra_link_args=[
-        "-Wl,-rpath=/usr/local/lib/python3.9/dist-packages/maix/_maix_opencv",
-        "-Wl,-rpath=/usr/local/lib/python3.9/dist-packages/maix/",
-    ],
-    extra_compile_args=['-std=c++11', '-std=gnu++11' ],
-)
-
-
 _maix_image_module = Pybind11Extension(
     name = "_maix_image",
     include_dirs=[
@@ -111,16 +85,16 @@ _maix_display_module = Pybind11Extension(
 max_nn_srcs = get_srcs('ext_modules/_maix_nn/src')
 max_nn_srcs.extend(get_srcs('ext_modules/libmaix/components/libmaix/src'))
 max_nn_srcs.remove("ext_modules/libmaix/components/libmaix/src/libmaix.c")
-max_nn_srcs.remove("ext_modules/_maix_nn/src/py_maix_nn_app.c")
-max_nn_srcs.remove("ext_modules/_maix_nn/src/py_maix_nn_app_classifier.c")
-max_nn_srcs.remove("ext_modules/_maix_nn/src/py_maix_nn_app_FaceRecognize.c")
-max_nn_srcs.remove("ext_modules/_maix_nn/src/py_maix_nn_decoder_yolo2.c")
-max_nn_srcs.remove("ext_modules/_maix_nn/src/py_maix_nn_decoder.c")
+# max_nn_srcs.remove("ext_modules/_maix_nn/src/py_maix_nn_app.c")
+# max_nn_srcs.remove("ext_modules/_maix_nn/src/py_maix_nn_app_classifier.c")
+# max_nn_srcs.remove("ext_modules/_maix_nn/src/py_maix_nn_app_FaceRecognize.c")
+# max_nn_srcs.remove("ext_modules/_maix_nn/src/py_maix_nn_decoder_yolo2.c")
+# max_nn_srcs.remove("ext_modules/_maix_nn/src/py_maix_nn_decoder.c")
 # max_nn_srcs.remove("ext_modules/_maix_nn/src/py_maix_nn.c")
 _maix_nn_module = Extension('_maix_nn', include_dirs=['ext_modules/_maix_nn/include', 'ext_modules/libmaix/components/libmaix/include'],
                             sources=max_nn_srcs,
                             libraries=[
-    "maix_utils", "maix_nn",
+    "maix_utils", "maix_nn", "maix_nn_decoder", "maix_nn_app"
 ],
     library_dirs=[ ext_so, ],
     # extra_link_args  = [ "-Wl,-z,origin", "-Wl,-rpath='$ORIGIN/maix'" ]
@@ -162,7 +136,6 @@ _maix_modules = [
     libi2c_module,
     _maix_module,
     # _maix_vivo_module,
-    # _maix_opencv_module,
     _maix_speech_module,
     _maix_image_module,
     _maix_camera_module,
@@ -177,6 +150,7 @@ _maix_data_files = [
 ]
 
 _maix_py_modules = [
+    "numpy",
     "Pillow",
     "rpyc",
     "gpiod",
