@@ -33,41 +33,6 @@ _maix_vivo_module = Pybind11Extension("_maix_vivo",
     # define_macros=[('V831Camera', None)],
 )
 
-# python3.8 -m pip install pybind11
-_maix_opencv_module = Pybind11Extension("_maix_opencv",
-    include_dirs=[
-        get_incs(
-            'ext_modules/libmaix/components/libmaix/include'),
-        get_incs(
-            'ext_modules/libmaix/components/libmaix/lib/arch/v83x/include/opencv4/'),
-        get_incs(
-            'ext_modules/libmaix/components/maix_cv_image/include')
-    ],
-    sources = get_srcs('ext_modules/_maix_opencv') + get_srcs('ext_modules/libmaix/components/maix_cv_image/src'),
-    libraries=[
-        "maix_utils", "maix_cam", "maix_image",
-        "opencv_videoio", "opencv_highgui", "opencv_core", "opencv_imgproc", "opencv_imgcodecs", "opencv_freetype"
-        # "opencv_aruco", "opencv_dnn", "opencv_hfs", "opencv_optflow", "opencv_shape",
-        # "opencv_videoio","opencv_bgsegm", "opencv_dpm", "opencv_highgui", "opencv_phase_unwrapping", "opencv_stereo",
-        # "opencv_video", "opencv_bioinspired", "opencv_face", "opencv_imgcodecs", "opencv_photo",
-        # "opencv_stitching", "opencv_videostab", "opencv_calib3d", "opencv_features2d", "opencv_img_hash",
-        # "opencv_plot", "opencv_structured_light", "opencv_xfeatures2d", "opencv_ccalib", "opencv_flann",
-        # "opencv_imgproc", "opencv_quality", "opencv_superres", "opencv_ximgproc", "opencv_core", "opencv_freetype",
-        # "opencv_line_descriptor", "opencv_reg", "opencv_surface_matching", "opencv_xobjdetect", "opencv_datasets",
-        # "opencv_fuzzy", "opencv_ml", "opencv_rgbd", "opencv_text", "opencv_xphoto", "opencv_dnn_objdetect",
-        # "opencv_gapi", "opencv_objdetect", "opencv_saliency", "opencv_tracking"
-    ],
-    library_dirs=[
-        ext_so,
-        "./ext_modules/libmaix/components/libmaix/lib/arch/v83x/opencv4",
-    ],
-    extra_link_args=[
-        "-Wl,-rpath=/usr/lib/python3.8/site-packages/maix",
-        "-Wl,-rpath=/usr/lib/python3.8/site-packages/maix/_maix_opencv"
-    ],
-)
-
-
 # python3.8 -m pip install pybind11
 _maix_speech_module = Pybind11Extension("_maix_speech",
     include_dirs=[
@@ -207,7 +172,6 @@ _maix_modules = [
     _maix_module,
     _maix_vivo_module,
     _maix_image_module,
-    # _maix_opencv_module,
     # _maix_camera_module,
     _maix_speech_module,
     _maix_display_module,
@@ -220,6 +184,7 @@ _maix_data_files = [
 ]
 
 _maix_py_modules = [
+    "numpy",
     "Pillow",
     "rpyc",
     "gpiod",
