@@ -18,3 +18,15 @@ try:
   __all__.extend(['utils'])
 except ModuleNotFoundError as e:
   pass
+
+try:
+  import spidev as spi
+  __all__.extend(['spi'])
+except ModuleNotFoundError as e:
+  pass
+
+try:
+  import serial
+  __all__.extend(['serial'])
+except ModuleNotFoundError as e:
+  pass
